@@ -1,13 +1,13 @@
 
-#	      ___    __                          __         
-#	     /   |  / /___  _________  _________/ /__  _____
-#	    / /| | / / __ `/ ___/ __ \/ ___/ __  / _ \/ ___/
-#	   / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
-#	  /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
+#         ___    __                          __         
+#        /   |  / /___  _________  _________/ /__  _____
+#       / /| | / / __ `/ ___/ __ \/ ___/ __  / _ \/ ___/
+#      / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
+#     /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 #
 #
-#		ALACORDER beta 7.4.9.9.6
-#		by Sam Robson
+#       ALACORDER beta 7.4.9.9.7
+#       by Sam Robson
 #
 
 import os
@@ -29,18 +29,19 @@ import PyPDF2
 from io import StringIO
 
 # CONFIG
-# conf = pd.Series({'in_path': in_path, 'out_path': out_path, 'in_ext': in_ext, 'out_ext': out_ext, 'archive': fromArchive, 'origin': origin, 'make': make, 'contents': contents, 'batches': batches, 'case_max': case_max, 'tot_batches': tot_batches, 'batchsize': batchsize, 'print_log': print_log, 'warnings': warn, 'flags': flags, 'save_archive': save_archive}) 
+#conf = pd.Series({'in_path': in_path, 'out_path': out_path, 'in_ext': in_ext, 'out_ext': out_ext, 'archive': fromArchive, 'origin': origin, 'make': make, 'contents': contents, 'batches': batches, 'case_max': case_max, 'tot_batches': tot_batches, 'batchsize': batchsize, 'print_log': print_log, 'warnings': warn, 'flags': flags, 'save_archive': save_archive})
+
 def config(in_path, out_path="", flags="", print_log=True, warn=False, save_archive=False, set_batch=0, max_cases=0): 
 
 	path_input = True if isinstance(in_path,str) else False
 	input_cap = True if max_cases > 0 else False
 	out_ext: str = out_path.split(".")[-1].strip()
-    
+	
 	if path_input == True:
 		in_ext: str = in_path.split(".")[-1].strip() if len(in_path.split(".")[-1])<5 else "directory" 
 	else:
 		in_ext = "object"
-        in_path = "no_import"
+		in_path = "no_import"
 		origin = "archive"
 		make = "table"
 
@@ -64,66 +65,68 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 	make = ""
 	origin = ""
 	contents = []
-    paths = []
+	paths = []
 
 	# Set read, write modes, contents
 	if in_ext == "directory" and bool(out_ext == "pkl" or out_ext == "xz" or out_ext == "txt"): 
 		make = "archive"
 		origin = "directory"
 		paths = glob.glob(in_path + '**/*.pdf', recursive=True)
-        if print_log == True:
-		    print(paths.describe())
+		if print_log == True:
+			print(paths.describe())
 	if in_ext == "pdf":
 		in_ext = "directory"
 		paths = [in_path]
 		origin = "directory"
 		make = "archive"
-        if print_log == True:
-		    print(paths)
-    if in_ext == "txt":
-        origin = "archive"
-        make = "table"
-        with open(in_path,'r') as textfile:
-            contents = textfile.read()
-            if print_log == True:
-                print(contents)
+		if print_log == True:
+			print(paths)
+	if in_ext == "txt":
+		origin = "archive"
+		make = "table"
+		with open(in_path,'r') as textfile:
+			contents = textfile.read()
+			if print_log == True:
+				print(contents)
 	if in_ext == "directory" and bool(out_ext == "xls" or  out_ext == "no_export" or out_ext == "json" or out_ext == "csv" or out_ext == "txt" or out_ext == "dta"):
 		make = "table"
 		origin = "directory"
 		paths = glob.glob(in_path + '**/*.pdf', recursive=True)
-        if print_log == True:
-		    print(paths.describe())
+		if print_log == True:
+			print(paths.describe())
 	if in_ext == "pkl":
 		make = "table"
 		origin = "archive"
-        try:
-		    contents = pd.read_pickle(in_path)['AllPagesText']
-		    fromArchive = True
-            if print_log == True:
-		        print(contents.describe())
+		try:
+			contents = pd.read_pickle(in_path)['AllPagesText']
+			fromArchive = True
+			if print_log == True:
+				print(contents.describe())
+		except KeyError:
+			pass
 	if in_ext == "xz":
 		make = "table"
 		origin = "archive"
 		contents = pd.read_pickle(in_path,compression="xz")['AllPagesText']
 		fromArchive = True
-        if print_log == True:
-		    print(contents.describe())
+		if print_log == True:
+			print(contents.describe())
 	if in_ext == "object" and origin == "archive":
 		contents = in_path['AllPagesText']
-        if print_log == True:
-		    print(contents.describe())
-    if out_ext == "no_export" and origin == "archive":
-        try:
-            contents = in_path['AllPagesText']
-            if print_log == True:
-    		    print(contents.describe())
-        except KeyError:
-            try:
-                contents = str(in_path)
-                if print_log == True:
-        		    print(contents.describe())
-            except (KeyError, TypeError):
-                raise Exception("Could not find series \'All Pages Text\' in archive file. Create new archive, check version compatability, or edit pickle archive using pandas to reattempt.")
+		if print_log == True:
+			print(contents.describe())
+	if out_ext == "no_export" and origin == "archive":
+		try:
+			contents = in_path['AllPagesText']
+			if print_log == True:
+				print(contents.describe())
+		except KeyError:
+			try:
+				contents = str(in_path)
+				if print_log == True:
+					print(contents.describe())
+			except (KeyError, TypeError):
+				raise Exception("Could not find series \'All Pages Text\' in archive file. Create new archive, check version compatability, or edit pickle archive using pandas to reattempt.")
 
 	if input_cap == True:
 		contents = contents[0:max_cases]
@@ -143,8 +146,8 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 	tot_batches = math.ceil(case_max / batchsize)
 	batches = np.array_split(contents, tot_batches)
 	batchsize = len(batches[0])
-    
-    write = True if out_ext != "no_export" else False
+	
+	write = True if out_ext != "no_export" else False
 
 	if print_log == True:
 		print(f"\nInitial configuration succeeded!\n\nIn:   {in_path} \nOut:    {out_path}\n\n{case_max} cases...\n")
@@ -158,10 +161,10 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 		'origin': origin,
 		'make': make,
 		'contents': contents,
-        'paths': paths,
+		'paths': paths,
 		'batches': batches,
 		'case_max': case_max,
-        'write': write,
+		'write': write,
 		'tot_batches': tot_batches,
 		'batchsize': batchsize,
 		'print_log': print_log,
@@ -181,7 +184,7 @@ def writeArchive(conf):
 	tot_batches = conf['tot_batches']
 	batchsize = conf['batchsize']
 	batches = conf['batches']
-    paths = conf['paths']
+	paths = conf['paths']
 	contents = conf['contents']
 	in_ext = conf['in_ext']
 	out_ext = conf['out_ext']
@@ -239,7 +242,7 @@ def writeTables(conf):
 	print_log = conf['print_log']
 	warn = conf['warnings']
 	contents = conf['contents']
-    paths = conf['paths']
+	paths = conf['paths']
 	batches = conf['batches']
 	save_archive = conf['save_archive']
 	from_archive = conf[is_text]
@@ -304,7 +307,7 @@ def writeTables(conf):
 	feesheet = feesheet.dropna() 
 	fees = fees.dropna()
 	feesheet = feesheet.tolist() # -> [df, df, df]
-    
+	
 	try:
 		feesheet = pd.concat(feesheet,axis=0,ignore_index=True) #  -> batch df
 	except ValueError:
@@ -321,7 +324,7 @@ def writeTables(conf):
 	chargetabs = chargetabs.dropna()
 	charges = charges.dropna()
 	chargetabs = chargetabs.tolist()
-    
+	
 	try:
 		chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
 	except ValueError:
@@ -401,7 +404,7 @@ def writeFees(conf):
 	out_ext = conf['out_ext']
 	print_log = conf['print_log']
 	warn = conf['warnings']
-    paths = conf['paths']
+	paths = conf['paths']
 	contents = conf['contents']
 	batches = conf['batches']
 	from_archive = conf[is_text]
@@ -475,7 +478,7 @@ def writeCharges(conf):
 	in_ext = conf['in_ext']
 	out_ext = conf['out_ext']
 	print_log = conf['print_log']
-    paths = conf['paths']
+	paths = conf['paths']
 	warn = conf['warnings']
 	contents = conf['contents']
 	batches = conf['batches']
@@ -558,15 +561,15 @@ def parse(conf, method, status=''):
 	print_log = conf['print_log']
 	warn = conf['warnings']
 	contents = conf['contents']
-    paths = conf['paths']
+	paths = conf['paths']
 	batches = conf['batches']
 	from_archive = conf['is_text']
-    write = conf['write']
+	write = conf['write']
 	if warn == False:
 		warnings.filterwarnings("ignore")
 	start_time = time.time()
 	alloutputs = pd.Series()
-    on_batch = 0
+	on_batch = 0
 	uselist = False
 	for i, c in enumerate(batches):
 		exptime = time.time()
@@ -579,32 +582,32 @@ def parse(conf, method, status=''):
 
 		customoutputs = allpagestext.map(lambda x: method(x))
 		alloutputs = alloutputs.append(customoutputs)
-        
+		
 		if print_log == True or out_ext != "no_export":
 			print(alloutputs)
-        
-        if write == True:
-    		if out_ext == "xls":
-    			with pd.ExcelWriter(path_out) as writer:
-    				alloutputs.to_excel(writer, sheet_name="output-table")
-    		elif out_ext == "pkl":
-    			alloutputs.to_pickle(path_out+".xz",compression="xz")
-    		elif out_ext == "xz":
-    			alloutputs.to_pickle(path_out,compression="xz")
-    		elif out_ext == "json":
-    			alloutputs.to_json(path_out)
-    		elif out_ext == "csv":
-    			alloutputs.to_csv(path_out,escapechar='\\')
-    		elif out_ext == "md":
-    			alloutputs.to_markdown(path_out)
-    		elif out_ext == "txt":
-    			alloutputs.to_string(path_out)
-    		elif out_ext == "dta":
-    			alloutputs.to_stata(path_out)
-    		elif out_ext == "no_export" or print_log == True:
-    			print(alloutputs.to_string())
-    		else:
-    			raise Warning("Batch export failed!")
+		
+		if write == True:
+			if out_ext == "xls":
+				with pd.ExcelWriter(path_out) as writer:
+					alloutputs.to_excel(writer, sheet_name="output-table")
+			elif out_ext == "pkl":
+				alloutputs.to_pickle(path_out+".xz",compression="xz")
+			elif out_ext == "xz":
+				alloutputs.to_pickle(path_out,compression="xz")
+			elif out_ext == "json":
+				alloutputs.to_json(path_out)
+			elif out_ext == "csv":
+				alloutputs.to_csv(path_out,escapechar='\\')
+			elif out_ext == "md":
+				alloutputs.to_markdown(path_out)
+			elif out_ext == "txt":
+				alloutputs.to_string(path_out)
+			elif out_ext == "dta":
+				alloutputs.to_stata(path_out)
+			elif out_ext == "no_export" or print_log == True:
+				print(alloutputs.to_string())
+			else:
+				raise Warning("Batch export failed!")
 		on_batch += 1
 	log_complete(conf, start_time)
 	on_batch = 0
@@ -709,7 +712,7 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		street_addr = ""
 	try:
-		zip_code = re.search(r'(Zip\: )(.+)', str(text), re.MULTILINE).group(2).strip()	
+		zip_code = re.search(r'(Zip\: )(.+)', str(text), re.MULTILINE).group(2).strip() 
 	except (IndexError, AttributeError):
 		zip_code = ""
 	try:
@@ -762,17 +765,17 @@ def getFeeSheet(text: str, cnum: str):
 		amtholdrows = drows.map(lambda x: str(x[3]).strip() if len(x)>5 else "")
 		amtholdrows = amtholdrows.map(lambda x: x.split(" ")[0].strip() if " " in x else x)
 		istotalrow = fees.map(lambda x: False if bool(re.search(r'(ACTIVE)',x)) else True)
-        try:
-            adminfeerows = pd.Series(actives).str.strip().split(" ")[1].strip()
-        except IndexError:
-            adminfeerows = ""
-        
+		try:
+			adminfeerows = pd.Series(actives).str.strip().split(" ")[1].strip()
+		except IndexError:
+			adminfeerows = []
+		
 
 		feesheet = pd.DataFrame({
 			'CaseNumber': cnum,
 			'Total': '',
-            'FeeStatus': 'ACTIVE',
-            'AdminFee': 
+			'FeeStatus': 'ACTIVE',
+			'AdminFee': adminfeerows.tolist()
 			'Code': coderows.tolist(),
 			'Payor': payorrows.tolist(),
 			'AmtDue': amtduerows.tolist(),
@@ -784,8 +787,8 @@ def getFeeSheet(text: str, cnum: str):
 		totalrdf = {
 			'CaseNumber': cnum,
 			'Total': 'TOTAL',
-            'FeeStatus': '',
-            'AdminFee': '',
+			'FeeStatus': '',
+			'AdminFee': '',
 			'Code': '',
 			'Payor': '',
 			'AmtDue': tdue,
@@ -809,10 +812,10 @@ def getFeeSheet(text: str, cnum: str):
 		allrows = actives
 		allrows.append(totalrow)
 		allrowstr = "\n".join(allrows)
-        
-        cols = ['CaseNumber', 'Total', 'FeeStatus', 'AdminFee', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']
-        feesheet = feesheet[cols]
-        
+		
+		cols = ['CaseNumber', 'Total', 'FeeStatus', 'AdminFee', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']
+		feesheet = feesheet[cols]
+		
 		return [tdue, tbal, d999, owe_codes, codes, allrowstr, feesheet]
 
 def getCharges(text: str, cnum: str):
@@ -855,7 +858,7 @@ def getCharges(text: str, cnum: str):
 	try:
 		charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^a-z]{1,2}?.{1}-[^\s]{3}-[^\s]{3})', x).group())
 	except (AttributeError, IndexError):
-		pass	
+		pass    
 		try:
 			charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([0-9]{1,2}.{1}-.{3}-.{3})',x).group()) # TEST
 		except (AttributeError, IndexError):
@@ -975,16 +978,16 @@ def log_complete(conf, start_time):
 	elapsed = completion_time - start_time
 	cases_per_sec = case_max/elapsed
 	print(f'''
-	      ___    __                          __         
-	     /   |  / /___  _________  _________/ /__  _____
-	    / /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
+		  ___    __                          __         
+		 /   |  / /___  _________  _________/ /__  _____
+		/ /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
 	   / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
 	  /_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 
 
 
-	ALACORDER beta 7.4.9.9.6
-	by Sam Robson	
+	ALACORDER beta 7.4.9.9.7
+	by Sam Robson   
 
 	Searched {path_in} 
 	{path_out} 
